==> haskell-hspec-2.3.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.3.2
id: hspec-2.3.2-AN9xcjaacLKEAAGjKcxxHS
key: hspec-2.3.2-AN9xcjaacLKEAAGjKcxxHS
license: MIT
copyright: (c) 2011-2015 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell. It is inspired by
    the Ruby library RSpec. Some of Hspec'\''s distinctive features
    are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Core Test.Hspec.Discover
    Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
    Test.Hspec.Runner
hidden-modules: Paths_hspec
abi: c0e76809c2c609aff5ceff3f7b60dd3e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/hspec-2.3.2
hs-libraries: HShspec-2.3.2-AN9xcjaacLKEAAGjKcxxHS
depends:
    HUnit-1.5.0.0-CCvWASKpeWzFD7O0KoAt2G
    QuickCheck-2.9.2-AzbjWrJo3WFD60ZxKurQ3s base-4.9.0.0
    call-stack-0.1.0-izRGIczcaH64KMRs1Wg8q
    hspec-core-2.3.2-xWStsg2jmnFtpUwJJk2IZ
    hspec-discover-2.3.2-J0NJiyPACXT2hD0Fzd5zHR
    hspec-expectations-0.8.2-1072fqsbfP2JJmrxjGMoIt
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.4.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.4.2
id: hspec-2.4.2-CnnDihjCF11GnxZKqbree5
key: hspec-2.4.2-CnnDihjCF11GnxZKqbree5
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell. It is inspired by
    the Ruby library RSpec. Some of Hspec'\''s distinctive features
    are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Core Test.Hspec.Discover
    Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
    Test.Hspec.Runner
hidden-modules: Paths_hspec
abi: cf90e40d349415fcce2e5122f854e970
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.4.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/hspec-2.4.2
hs-libraries: HShspec-2.4.2-CnnDihjCF11GnxZKqbree5
depends:
    HUnit-1.5.0.0-CCvWASKpeWzFD7O0KoAt2G
    QuickCheck-2.9.2-AzbjWrJo3WFD60ZxKurQ3s base-4.9.0.0
    call-stack-0.1.0-izRGIczcaH64KMRs1Wg8q
    hspec-core-2.4.2-CY6Kzv9SvViIVjfSQFCrQA
    hspec-discover-2.4.2-1bDoAuyJjV78dJTSwmbu3i
    hspec-expectations-0.8.2-1072fqsbfP2JJmrxjGMoIt
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
